@@ -63,11 +63,10 @@ def handle_delete_functions():
 
 
 def handle_deploy_infrastructure_schedules():
-    _, project_to_config = get_master_config()
-    for project, config_dict in project_to_config.items():
-        info = const.PROJECTS_TO_API_KEYS[project]
-        client = cdf.experimental_client(info.project)
-        execute(client)
+    function_name, project = sys.argv[2].split("@")
+    info = const.PROJECTS_TO_API_KEYS[project]
+    client = cdf.experimental_client(info.project)
+    execute(client)
 
 
 def handle_call_schedulemanager():
